@@ -20,7 +20,7 @@ do_view_action() {
          fi
         ;;
     cat)
-        /bin/cat "${MC_EXT_FILENAME}" 2>/dev/null
+        cat "${MC_EXT_FILENAME}" 2>/dev/null
         ;;
     ar)
         file "${MC_EXT_FILENAME}" && nm -C "${MC_EXT_FILENAME}"
@@ -71,7 +71,7 @@ do_open_action() {
         sqlite3 "${MC_EXT_FILENAME}"
         ;;
     glade)
-        if glade-3 --version >/dev/null 2>&1; then
+        if which glade-3 >/dev/null 2>&1; then
             (glade-3 "${MC_EXT_FILENAME}" >/dev/null 2>&1 &)
         else
             (glade-2 "${MC_EXT_FILENAME}" >/dev/null 2>&1 &)
